@@ -20,7 +20,7 @@
 #
 
 from django.contrib import admin
-from models import *
+from .models import *
 
 admin.site.register(Deliverable)
 admin.site.register(DeliverableProperty)
\ No newline at end of file
