@@ -36,6 +36,8 @@ from shipping.models import DeliverableProperty
 def fretefacil_shipping_handler(request, form, order=None):
     if request.session.get("free_shipping"): return
     settings.use_editable()
+    if form is not None: user_postcode = form.cleaned_data['shipping_detail_postcode']
+    else: user_postcode = settings.STORE_POSTCODE 
     user_postcode = form.cleaned_data['shipping_detail_postcode']
     shippingservice = FreteFacilShippingService()
     cart = Cart.objects.from_request(request)
@@ -52,4 +54,4 @@ def fretefacil_shipping_handler(request, form, order=None):
                                                                  props.length,
                                                                  props.weight)
                 delivery_value += float(shippingservice.delivery_value(deliverable))
-    set_shipping(request, _("Correios"),delivery_value)
\ No newline at end of file
+    set_shipping(request, _("Correios"),delivery_value)
