@@ -23,11 +23,11 @@ from django.db.models import *
 from django.conf import settings
 from django.contrib.auth.models import User
 from django.template import Context,Template
-from datetime import date
-
-locale = settings.LOCALE_DATE
+from django.utils.timezone import now
 
 class DeliverableProperty(Model):
+    class Meta:
+        verbose_name_plural = "Deliverable Properties"
     sku = CharField(default='',max_length=20)
     height = IntegerField(default=16)
     length = IntegerField(default=16)
@@ -36,7 +36,7 @@ class DeliverableProperty(Model):
 
 class Deliverable(Model):
     name = CharField(default='((',max_length=50)
-    user = ForeignKey(User,related_name='+')
+    user = ForeignKey(User,related_name='+', on_delete=CASCADE)
     product = IntegerField(default=1)
     mail_code = CharField(default='',max_length=100)
     height = IntegerField(default=1)
@@ -44,7 +44,7 @@ class Deliverable(Model):
     width = IntegerField(default=1)
     weight = IntegerField(default=10)
     value = FloatField(default=0.0)
-    date = DateTimeField(default=date.today(),auto_now_add=True)
+    date = DateTimeField(default=now)
     def token(self): return self.name[:2]
     def name_trimmed(self): return self.name.split(';')[0][1:]
-    def month(self): return locale[self.date.month-1]
\ No newline at end of file
+    def month(self): return date.strftime('%b')
